aboutsummaryrefslogtreecommitdiff
path: root/src/simplewallet
diff options
context:
space:
mode:
authorwowario <wowario@protonmail.com>2019-11-13 10:17:45 +0300
committerwowario <wowario@protonmail.com>2019-11-13 10:24:10 +0300
commit67b4a19edf7b9d6a407a79eca5c57819863bfd71 (patch)
tree8949c802e7fa0b80f70ab42d2ebfd37ec07b2579 /src/simplewallet
parentMerge pull request #6097 (diff)
downloadmonero-67b4a19edf7b9d6a407a79eca5c57819863bfd71.tar.xz
simplewallet: noob-friendly help menu
Diffstat (limited to 'src/simplewallet')
-rw-r--r--src/simplewallet/simplewallet.cpp53
-rw-r--r--src/simplewallet/simplewallet.h1
2 files changed, 43 insertions, 11 deletions
diff --git a/src/simplewallet/simplewallet.h b/src/simplewallet/simplewallet.h
index 75bd893d5..e401f5fda 100644
--- a/src/simplewallet/simplewallet.h
+++ b/src/simplewallet/simplewallet.h
@@ -154,6 +154,7 @@ namespace cryptonote
bool set_persistent_rpc_client_id(const std::vector<std::string> &args = std::vector<std::string>());
bool set_auto_mine_for_rpc_payment_threshold(const std::vector<std::string> &args = std::vector<std::string>());
bool set_credits_target(const std::vector<std::string> &args = std::vector<std::string>());
+ bool help_advanced(const std::vector<std::string> &args = std::vector<std::string>());
bool help(const std::vector<std::string> &args = std::vector<std::string>());
bool start_mining(const std::vector<std::string> &args);
bool stop_mining(const std::vector<std::string> &args);
diff --git a/src/simplewallet/simplewallet.cpp b/src/simplewallet/simplewallet.cpp
index ea8f6f2f5..ddbdc3e15 100644
--- a/src/simplewallet/simplewallet.cpp
+++ b/src/simplewallet/simplewallet.cpp
@@ -121,7 +121,7 @@ typedef cryptonote::simple_wallet sw;
#define SCOPED_WALLET_UNLOCK() SCOPED_WALLET_UNLOCK_ON_BAD_PASSWORD(return true;)
-#define PRINT_USAGE(usage_help) fail_msg_writer() << boost::format(tr("usage: %s")) % usage_help;
+#define PRINT_USAGE(usage_help_advanced) fail_msg_writer() << boost::format(tr("usage: %s")) % usage_help_advanced;
#define LONG_PAYMENT_ID_SUPPORT_CHECK() \
do { \
@@ -268,7 +268,8 @@ namespace
const char* USAGE_START_MINING_FOR_RPC("start_mining_for_rpc");
const char* USAGE_STOP_MINING_FOR_RPC("stop_mining_for_rpc");
const char* USAGE_VERSION("version");
- const char* USAGE_HELP("help [<command>]");
+ const char* USAGE_HELP_ADVANCED("help_advanced [<command>]");
+ const char* USAGE_HELP("help");
std::string input_line(const std::string& prompt, bool yesno = false)
{
@@ -2315,7 +2316,7 @@ bool simple_wallet::on_unknown_command(const std::vector<std::string> &args)
{
if (args[0] == "exit" || args[0] == "q") // backward compat
return false;
- fail_msg_writer() << boost::format(tr("Unknown command '%s', try 'help'")) % args.front();
+ fail_msg_writer() << boost::format(tr("Unknown command '%s', try 'help_advanced'")) % args.front();
return true;
}
@@ -3044,13 +3045,37 @@ bool simple_wallet::set_export_format(const std::vector<std::string> &args/* = s
bool simple_wallet::help(const std::vector<std::string> &args/* = std::vector<std::string>()*/)
{
+ message_writer() << "";
+ message_writer() << tr("Commands:");
+ message_writer() << "";
+ message_writer() << tr("\"welcome\" - Read welcome message.");
+ message_writer() << tr("\"donate <amount>\" - Donate XMR to the development team.");
+ message_writer() << tr("\"balance\" - Show balance.");
+ message_writer() << tr("\"address new\" - Create new subaddress.");
+ message_writer() << tr("\"address all\" - Show all addresses.");
+ message_writer() << tr("\"transfer <address> <amount>\" - Send XMR to an address.");
+ message_writer() << tr("\"show_transfers [in|out|pending|failed|pool]\" - Show transactions.");
+ message_writer() << tr("\"sweep_all <address>\" - Send whole balance to another wallet.");
+ message_writer() << tr("\"seed\" - Show secret 25 words that can be used to recover this wallet.");
+ message_writer() << tr("\"refresh\" - Synchronize wallet with the Monero network.");
+ message_writer() << tr("\"status\" - Check current status of wallet.");
+ message_writer() << tr("\"version\" - Check software version.");
+ message_writer() << tr("\"help_advanced\" - Show list with more available commands.");
+ message_writer() << tr("\"save\" - Save wallet.");
+ message_writer() << tr("\"exit\" - Exit wallet.");
+ message_writer() << "";
+ return true;
+}
+
+bool simple_wallet::help_advanced(const std::vector<std::string> &args/* = std::vector<std::string>()*/)
+{
if(args.empty())
{
success_msg_writer() << get_commands_str();
}
else if ((args.size() == 2) && (args.front() == "mms"))
{
// Little hack to be able to do "help mms <subcommand>"
std::vector<std::string> mms_args(1, args.front() + " " + args.back());
success_msg_writer() << get_command_usage(mms_args);
}
@@ -3439,7 +3464,7 @@ simple_wallet::simple_wallet()
"<subcommand> is one of:\n"
" init, info, signer, list, next, sync, transfer, delete, send, receive, export, note, show, set, help\n"
" send_signer_config, start_auto_config, stop_auto_config, auto_config\n"
- "Get help about a subcommand with: help mms <subcommand>, or mms help <subcommand>"));
+ "Get help about a subcommand with: help_advanced mms <subcommand>"));
m_cmd_binder.set_handler("mms init",
boost::bind(&simple_wallet::on_command, this, &simple_wallet::mms, _1),
tr(USAGE_MMS_INIT),
@@ -3589,10 +3614,14 @@ simple_wallet::simple_wallet()
boost::bind(&simple_wallet::stop_mining_for_rpc, this, _1),
tr(USAGE_STOP_MINING_FOR_RPC),
tr("Stop mining to pay for RPC access"));
+ m_cmd_binder.set_handler("help_advanced",
+ boost::bind(&simple_wallet::on_command, this, &simple_wallet::help_advanced, _1),
+ tr(USAGE_HELP_ADVANCED),
+ tr("Show the help section or the documentation about a <command>."));
m_cmd_binder.set_handler("help",
boost::bind(&simple_wallet::on_command, this, &simple_wallet::help, _1),
tr(USAGE_HELP),
- tr("Show the help section or the documentation about a <command>."));
+ tr("Show simplified list of available commands."));
m_cmd_binder.set_unknown_command_handler(boost::bind(&simple_wallet::on_command, this, &simple_wallet::on_unknown_command, _1));
m_cmd_binder.set_empty_command_handler(boost::bind(&simple_wallet::on_empty_command, this));
m_cmd_binder.set_cancel_handler(boost::bind(&simple_wallet::on_cancelled_command, this));
@@ -4744,8 +4773,9 @@ boost::optional<epee::wipeable_string> simple_wallet::new_wallet(const boost::pr
"**********************************************************************\n" <<
tr("Your wallet has been generated!\n"
"To start synchronizing with the daemon, use the \"refresh\" command.\n"
- "Use the \"help\" command to see the list of available commands.\n"
- "Use \"help <command>\" to see a command's documentation.\n"
+ "Use the \"help\" command to see a simplified list of available commands.\n"
+ "Use the \"help_advanced\" command to see an advanced list of available commands.\n"
+ "Use \"help_advanced <command>\" to see a command's documentation.\n"
"Always use the \"exit\" command when closing monero-wallet-cli to save \n"
"your current session's state. Otherwise, you might need to synchronize \n"
"your wallet again (your wallet keys are NOT at risk in any case).\n")
@@ -5004,8 +5034,9 @@ boost::optional<epee::wipeable_string> simple_wallet::open_wallet(const boost::p
}
success_msg_writer() <<
"**********************************************************************\n" <<
- tr("Use the \"help\" command to see the list of available commands.\n") <<
- tr("Use \"help <command>\" to see a command's documentation.\n") <<
+ tr("Use the \"help\" command to see a simplified list of available commands.\n") <<
+ tr("Use the \"help_advanced\" command to see an advanced list of available commands.\n") <<
+ tr("Use \"help_advanced <command>\" to see a command's documentation.\n") <<
"**********************************************************************";
return password;
}
@@ -11016,7 +11047,7 @@ void simple_wallet::mms_help(const std::vector<std::string> &args)
{
if (args.size() > 1)
{
- fail_msg_writer() << tr("Usage: mms help [<subcommand>]");
+ fail_msg_writer() << tr("Usage: help_advanced mms [<subcommand>]");
return;
}
std::vector<std::string> help_args;
@@ -3044,13 +3045,37 @@ bool simple_wallet::set_export_format(const std::vector<std::string> &args/* = s
else if ((args.size() == 2) && (args.front() == "mms"))
{
- // Little hack to be able to do "help mms <subcommand>"
+ // Little hack to be able to do "help_advanced mms <subcommand>"
std::vector<std::string> mms_args(1, args.front() + " " + args.back());
success_msg_writer() << get_command_usage(mms_args);